Struct ContinuousTxTransaction
Source pub struct ContinuousTxTransaction<'ch> { }
An in-progress continuous TX transaction
Stop transaction when the current iteration ends.
Stop transaction as soon as possible.
SourceAvailable on crate feature unstable only.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.